@@ -32,8 +32,8 @@ print.findFn <- function(x,
   }
   if (length(where)>1)
     stop("if length(where)>1, ", 
-      "where must names columns of", 
-      " x;  they do not.  where = ",
+      "where must be names of columns of", 
+      " x;  they are not.  where = ",
          paste(where, collapse=", "))
   if (toupper(where) == "HTML") {
     f0 <- tempfile()
@@ -50,25 +50,14 @@ print.findFn <- function(x,
     File <- where
   }
 ##
-## 2.  Get call including search
-##     string
+## 2.  title, Dir?
 ##
-#  cl <- match.call()
-  Ocall <- attr(x, "call")
-  Oc0 <- deparse(Ocall)
-  Oc. <- gsub('\"', "'", Oc0)
-  Oc1 <- paste(cl, "<-", Oc.)
-#  Oc2 <- paste0('For a package summary:  ', 
-  Oc2 <- paste0('installPackages(', cl, 
-    ');  writeFindFn2xls(', cl, ')')
-#  ocall <- paste(cl, "<-", Oc1)
-#  ocall <- parse(text=Ocx)
   string <- attr(x, "string")
-##
-## 3.  title, Dir?
-##
   if (missing(title)) {
-    title <- string
+    title <- paste('Help pages for', string)
+    titSum <- paste('package summary for', string)
+  } else {
+    titSum <- paste('packageSum(', string, ')')
   }
   Dir <- dirname(File)
   if (Dir == ".") {
@@ -78,7 +67,29 @@ print.findFn <- function(x,
     dc0 <- dir.create(Dir, FALSE, TRUE)
   }
 ##
-## 4.  sorttable.js?
+## 3.  print(packageSum(...))
+##   ... moved to the end 
+#  if((toupper(where)=='HTML') && openBrowser){
+#    sumLink <- print(packageSum(x, title=title, ...))
+#  } else sumLink <- ''
+##
+## 4.  Get call including search
+##     string
+##
+#  cl <- match.call()
+  Ocall <- attr(x, "call")
+  Oc0 <- deparse(Ocall)
+  Oc. <- gsub('\"', "'", Oc0)
+  if(Oc.=='NULL')Oc. <- '...'
+  Oc1 <- paste(cl, "<-", paste(Oc., collapse=''))
+#  Oc2 <- paste0('For a package summary:  ', 
+#  Oc2 <- paste0('For more info, call installPackages', 
+#          ' before packageSum')
+  pkgS <- paste0('packageSum(', cl, ',...)')
+#  ocall <- paste(cl, "<-", Oc1)
+#  ocall <- parse(text=Ocx)
+##
+## 5.  sorttable.js?
 ##
 ##  Dir <- tools:::file_path_as_absolute( dirname(File) )
 ##  This line is NOT ENOUGH:
@@ -93,16 +104,19 @@ print.findFn <- function(x,
     file.copy(js, Dir)
   }
 ##
-## 5.  Modify x$Description
+## 6.  Modify x$Description
 ##
 ## save "x" as "xin" for debugging
   xin <- x
+# Allow x to have a NULL Description 
+# to simplify testing of other sos functions   
+  Desc <- x$Description 
+  if(is.null(Desc))Desc <- ''
   x$Description <- gsub("(^[ ]+)|([ ]+$)", 
-      "", as.character(x$Description),
-      useBytes = TRUE)
+      "", as.character(Desc), useBytes = TRUE)
   x[] <- lapply(x, as.character)
 ##
-## 6.  template for brew?
+## 7.  template for brew?
 ##
   hasTemplate <- !missing(template)
   if (!hasTemplate) {
@@ -118,9 +132,11 @@ print.findFn <- function(x,
 # str(ocall)
 #language findFn(string = "spline", maxPages = 1)
   assign("Oc1", Oc1, envir = xenv)
-  assign("Oc2", Oc2, envir = xenv)
-  ocall <- paste0(Oc1, '; ', Oc2)
-  assign("ocall", ocall, envir = xenv)
+#  assign("Oc2", Oc2, envir = xenv)
+  assign('pkgS', pkgS, envir=xenv)
+#  assign('sumLink', sumLink, envir=xenv)
+#  ocall <- paste0(Oc1, '; ', Oc2)
+#  assign("ocall", ocall, envir = xenv)
   assign("x", x, envir = xenv)
   ##
   brew::brew(template, File, envir = xenv)
@@ -128,7 +144,8 @@ print.findFn <- function(x,
     close(template)
   }
 ##
-## 7.  Was File created appropriately?  If no, try Sundar's original code
+## 8.  Was File created appropriately?  
+##       If no, try Sundar's original code
 ##
   FileInfo <- file.info(File)
   if (is.na(FileInfo$size) || FileInfo$size <= 0) {
@@ -209,7 +226,7 @@ print.findFn <- function(x,
 # str(ocall)
 #language findFn(string = "spline", maxPages = 1)    
     .cat("<h2>call: <font color='#800'>",
-         paste(ocall, collapse = ""), "</font></h2>\n")
+         paste(Ocall, collapse = ""), "</font></h2>\n")
     .cat("<table class='sortable'>\n<thead>")
     link <- as.character(x$Link)
     desc <- gsub("(^[ ]+)|([ ]+$)", "", as.character(x$Description), useBytes = TRUE)
@@ -233,7 +250,7 @@ print.findFn <- function(x,
     .cat("</tbody></table></body></html>")
   }
   ##
-  ## 8.  Display in a browser?
+  ## 9.  Display in a browser?
   ##
   if (openBrowser) {
     FileInf2 <- file.info(File)
@@ -244,7 +261,11 @@ print.findFn <- function(x,
       if (FileInf2$size <= 0) {
         warning("0 bytes in file ", File, ";  nothing to give to a browser.")
       } else {
+#       display HTML "File";  browseURL accesses 
+#          variable(s) in this calling function 
+#          like 'title'   
         utils::browseURL(File)
+        print(packageSum(x, title=titSum, ...))
       }
     }
   }
